@@ -63,6 +63,8 @@ static void _zuluCryptDeleteDeadMountPoints( stringList_t stl,const char * m )
 	string_t st ;
 	string_t xt ;
 
+	const char * bl = zuluCryptBitLockerFolderPrefix() ;
+
 	DIR * dir = opendir( m ) ;
 
 	if( dir == NULL ){
@@ -74,7 +76,7 @@ static void _zuluCryptDeleteDeadMountPoints( stringList_t stl,const char * m )
 
 		e = entry->d_name ;
 
-		if( !StringAtLeastOneMatch_1( e,".","..","cryptoBitlocker",NULL ) ){
+		if( !StringAtLeastOneMatch_1( e,".","..",bl,NULL ) ){
 
 			st = String( e ) ;
 
@@ -113,7 +115,7 @@ void zuluCryptDeleteDeadMountPoints( uid_t uid,stringList_t stl )
 	StringDelete( &st ) ;
 }
 
-void zuluCryptClearDeadMappers( uid_t uid )
+void zuluCryptClearDeadMappers( uid_t uid,int s )
 {
 	struct crypt_device * cd ;
 	const char * dir_path = crypt_get_dir() ;
@@ -204,7 +206,11 @@ void zuluCryptClearDeadMappers( uid_t uid )
 		}
 	}
 
-	zuluCryptDeleteDeadMountPoints( uid,stl ) ;
+	if( s ){
+
+		zuluCryptDeleteDeadMountPoints( uid,stl ) ;
+	}
+
 	/*
 	 * zuluCryptSecurityDropElevatedPrivileges() is defined in security.c
 	 */
