@@ -66,13 +66,45 @@ static const char * _clean_loop_path( string_t xt )
 	}
 }
 
+/*
+ *  We only care about loop device path that are in a form of "/dev/loopX.
+ *
+ *  We dont care about loop device path that are in a form of /dev/loopXpY
+ *  and this method converts the latter path to the former if found.
+ */
+static string_t _loop_device_path( const char * device )
+{
+	string_t st ;
+
+	char * e = StringCopy_2( device ) ;
+	char * s = e + 10 ;
+
+	while( *s ){
+
+		if( *s == 'p' ){
+
+			*s = '\0' ;
+
+			break ;
+		}else{
+			s++ ;
+		}
+	}
+
+	st = String_1( "/sys/block/",e + 5,"/loop/backing_file",NULL ) ;
+
+	StringFree( e ) ;
+
+	return st ;
+}
+
 string_t zuluCryptLoopDeviceAddress_2( const char * device )
 {
 	int fd ;
 	char * path ;
 	struct loop_info64 l_info ;
 
-	string_t st = String_1( "/sys/block/",device + 5,"/loop/backing_file",NULL ) ;
+	string_t st = _loop_device_path( device ) ;
 
 	string_t xt = _StringGetFromVirtualFile( &st ) ;
 
@@ -111,7 +143,7 @@ char * zuluCryptLoopDeviceAddress_1( const char * device )
 	char * path ;
 	struct loop_info64 l_info ;
 
-	string_t st = String_1( "/sys/block/",device + 5,"/loop/backing_file",NULL ) ;
+	string_t st = _loop_device_path( device ) ;
 
 	string_t xt = _StringGetFromVirtualFile( &st ) ;
 
