@@ -333,6 +333,16 @@ const char * zuluCryptVolumeType( blkid_probe blkid,const char * device ) ;
  */
 int zuluCryptDeviceHasAgivenFileSystem( const char * device,const char * fs ) ;
 
+/*
+ * this function is defined in ./blkid_evaluate_tag.c
+ */
+int zuluCryptMultiPartitionLoopDevice( const char * e ) ;
+
+/*
+ * this function is defined in ./blkid_evaluate_tag.c
+ */
+int zuluCryptNoPartitionLoopDevice( const char * e ) ;
+
 /*
  * this function is defined in ./create_loop_device.c
  */
@@ -488,6 +498,11 @@ const char * zuluCryptBitLockerCreateMapperPath( string_t e,uid_t uid ) ;
  */
 int zuluCryptBitLockerVolume( const char * e ) ;
 
+/*
+ * this function is defined in bitlocker.c
+ */
+char * zuluCryptBitLockerUnmountPath( const char * e ) ;
+
 /*
  * this function is defined in bitlocker.c
  */
@@ -543,6 +558,11 @@ stringList_t zuluCryptGetMountInfoList_1( void ) ;
  */
 char * zuluCryptGetVolumeTypeFromMapperPath( const char * mapper ) ;
 
+/*
+ * this function is defined in status.c
+ */
+char * zuluCryptGetVolumeType_1( const char * m ) ;
+
 /*
  * this function is defined in create_volume.c
  */
