@@ -254,6 +254,13 @@ static string_t set_mount_options( m_struct * mst )
 				StringAppend( opt,",shortname=mixed" ) ;
 			}
 		}
+		if( StringsAreEqual( mst->fs,"ntfs" ) ){
+
+			if( StringDoesNotContain( opt,"big_writes" ) ){
+
+				StringAppend( opt,",big_writes" ) ;
+			}
+		}
 	}else if( fsFamily == OTHER_FAMILY_FS ){
 
 		if( StringDoesNotContain( opt,"uid=" ) ){
