@@ -30,6 +30,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 
+#include "luks2_support.h"
 #include "zuluplay_support.h"
 #include "share_mount_prefix_path.h"
 
@@ -45,7 +46,66 @@
 
 char * zuluCryptGetMountPointFromPath( const char * path ) ;
 
-static void _convert( char * buffer,int buffer_size,const char * s,u_int64_t y,u_int64_t z )
+typedef struct{
+	string_t integrity_hash ;
+	string_t integrity_keysize ;
+}authenticated_luks2 ;
+
+#ifdef CRYPT_LUKS2
+
+static int _is_authenticated_luks2( struct crypt_device * cd )
+{
+	struct crypt_params_integrity m ;
+
+	memset( &m,'\0',sizeof( m ) ) ;
+
+	if( crypt_get_integrity_info( cd,&m ) == 0 ){
+
+		return m.integrity != NULL ;
+	}else{
+		return 0 ;
+	}
+}
+
+static void _authenticated_luks2( struct crypt_device * cd,authenticated_luks2 * s )
+{
+	char buffer[ 1024 ] ;
+
+	struct crypt_params_integrity m ;
+
+	memset( &m,'\0',sizeof( m ) ) ;
+	memset( buffer,'\0',sizeof( buffer ) ) ;
+
+	if( crypt_get_integrity_info( cd,&m ) == 0 ){
+
+		if( m.integrity != NULL ){
+
+			s->integrity_hash = String_1( "/integrity: ",m.integrity,NULL ) ;
+		}
+
+		if( m.integrity_key_size != 0 ){
+
+			snprintf( buffer,sizeof( buffer ),
+				  "/integrity: %d bits",
+				  ( int )m.integrity_key_size * 8 ) ;
+
+			s->integrity_keysize = String( buffer ) ;
+		}
+	}
+}
+#else
+static void _authenticated_luks2( struct crypt_device * cd,authenticated_luks2 * s )
+{
+	if( s && cd ){}
+}
+static int _is_authenticated_luks2( struct crypt_device * cd )
+{
+	if( cd ){}
+	return 0 ;
+}
+#endif
+
+static void _convert( char * buffer,size_t buffer_size,const char * s,u_int64_t y,u_int64_t z )
 {
 	snprintf( buffer,buffer_size,"%.1f %s",( double )y/z,s ) ;
 }
@@ -69,10 +129,10 @@ void zuluCryptFormatSize( u_int64_t number,char * buffer,size_t buffer_size )
 		 _convert( buffer,buffer_size,"GB",number,1024 * 1024 * 1024 ) ;
 		 break ;
 	case 13: case 14 : case 15 :
-		 _convert( buffer,buffer_size,"TB",number,1024.0 * 1024 * 1024 * 1024 ) ;
+		 _convert( buffer,buffer_size,"TB",number,1024 * 1024 * 1024 * 1024ll ) ;
 		 break ;
 	default:
-		 _convert( buffer,buffer_size,"TB",number,1024.0 * 1024 * 1024 * 1024 ) ;
+		 _convert( buffer,buffer_size,"TB",number,1024 * 1024 * 1024 * 1024ll ) ;
 		 break ;
 	}
 }
@@ -286,24 +346,12 @@ int zuluCryptTrueCryptOrVeraCryptVolume( const char * mapper )
 	return StringAtLeastOneMatch_1( buffer,"TCRYPT","VCRYPT",NULL ) ;
 }
 
-char * zuluCryptGetVolumeTypeFromMapperPath( const char * mapper )
+static char * _get_type( struct crypt_device * cd,const char * mapper )
 {
-	struct crypt_device * cd ;
-	const char * type ;
 	char * r ;
 	string_t st ;
 
-	if( StringPrefixNotEqual( mapper,crypt_get_dir() ) ){
-
-		return StringCopy_2( "Nil" ) ;
-	}
-
-	if( crypt_init_by_name( &cd,mapper ) < 0 ){
-
-		return StringCopy_2( "Nil" ) ;
-	}
-
-	type = crypt_get_type( cd ) ;
+	const char * type = crypt_get_type( cd ) ;
 
 	if( type == NULL ){
 
@@ -318,11 +366,55 @@ char * zuluCryptGetVolumeTypeFromMapperPath( const char * mapper )
 			r = _get_type_from_udev( mapper ) ;
 		}
 	}else{
-		st = String_1( "crypto_",type,NULL ) ;
+		if( _is_authenticated_luks2( cd ) ){
+
+			st = String_1( "crypto_",type,"+",NULL ) ;
+		}else{
+			st = String_1( "crypto_",type,NULL ) ;
+		}
+
 		r = StringDeleteHandle( &st ) ;
 	}
 
+	return r ;
+}
+
+char * zuluCryptGetVolumeTypeFromMapperPath( const char * mapper )
+{
+	struct crypt_device * cd ;
+	char * r ;
+
+	if( crypt_init_by_name( &cd,mapper ) < 0 ){
+
+		return StringCopy_2( "Nil" ) ;
+	}
+
+	r = _get_type( cd,mapper ) ;
+
 	crypt_free( cd ) ;
+
+	return r ;
+}
+
+char * zuluCryptGetVolumeType_1( const char * device )
+{
+	struct crypt_device * cd ;
+	char * r ;
+
+	if( crypt_init( &cd,device ) != 0 ){
+
+		return StringCopy_2( "Nil" ) ;
+	}
+	if( crypt_load( cd,NULL,NULL ) != 0 ){
+
+		crypt_free( cd ) ;
+		return StringCopy_2( "Nil" ) ;
+	}
+
+	r = _get_type( cd,"" ) ;
+
+	crypt_free( cd ) ;
+
 	return r ;
 }
 
@@ -336,14 +428,19 @@ static void _device_info( string_t p,const char * device )
 
 	}else if( StringPrefixEqual( device,"/dev/loop" ) ){
 
-		path = zuluCryptLoopDeviceAddress_1( device ) ;
+		if( zuluCryptMultiPartitionLoopDevice( device ) ){
 
-		if( path != NULL ){
-
-			StringMultipleAppend( p,"\n device:   \t",device,"\n loop:   \t",path,NULL ) ;
-			StringFree( path ) ;
+			StringMultipleAppend( p,"\n device:   \t",device,"\n loop:   \t",device,NULL ) ;
 		}else{
-			StringMultipleAppend( p,"\n device:   \t",device,"\n loop:   \tNil",NULL ) ;
+			path = zuluCryptLoopDeviceAddress_1( device ) ;
+
+			if( path != NULL ){
+
+				StringMultipleAppend( p,"\n device:   \t",device,"\n loop:   \t",path,NULL ) ;
+				StringFree( path ) ;
+			}else{
+				StringMultipleAppend( p,"\n device:   \t",device,"\n loop:   \tNil",NULL ) ;
+			}
 		}
 	}else{
 		/*
@@ -531,6 +628,8 @@ static string_t _get_crypto_info_from_cryptsetup( const char * mapper )
 	int i = 0 ;
 	int j ;
 
+	authenticated_luks2 auth_luks2 ;
+
 	crypt_status_info info ;
 
 	struct crypt_device * cd ;
@@ -542,6 +641,10 @@ static string_t _get_crypto_info_from_cryptsetup( const char * mapper )
 		return StringVoid ;
 	}
 
+	memset( &auth_luks2,'\0',sizeof( auth_luks2 ) ) ;
+
+	_authenticated_luks2( cd,&auth_luks2 ) ;
+
 	p = String( mapper ) ;
 
 	info = crypt_status( cd,mapper ) ;
@@ -572,7 +675,14 @@ static string_t _get_crypto_info_from_cryptsetup( const char * mapper )
 		if( type != NULL ){
 
 			q = String( type ) ;
+
 			StringAppend( p,StringToLowerCase( q ) ) ;
+
+			if( StringsAreEqual_2( q,"luks2" ) && auth_luks2.integrity_hash ){
+
+				StringAppend( p,"+" ) ;
+			}
+
 			StringDelete( &q ) ;
 		}else{
 			q = _get_type_from_udev_1( mapper ) ;
@@ -600,9 +710,13 @@ static string_t _get_crypto_info_from_cryptsetup( const char * mapper )
 			StringAppend( p,"Nil" ) ;
 		}
 
+		StringAppendString( p,auth_luks2.integrity_hash ) ;
+
 		z = StringIntToString_1( buffer,SIZE,8 * crypt_get_volume_key_size( cd ) ) ;
 		StringMultipleAppend( p,"\n keysize:\t",z," bits",NULL ) ;
 
+		StringAppendString( p,auth_luks2.integrity_keysize ) ;
+
 		e = _crypt_get_data_offset( cd,mapper,type ) ;
 
 		z = StringIntToString_1( buffer,SIZE,e ) ;
@@ -648,6 +762,9 @@ static string_t _get_crypto_info_from_cryptsetup( const char * mapper )
 
 	crypt_free( cd ) ;
 
+	StringDelete( &auth_luks2.integrity_hash ) ;
+	StringDelete( &auth_luks2.integrity_keysize ) ;
+
 	return p ;
 }
 
