@@ -372,7 +372,7 @@ void createvolume::setOptions( int e )
 	 */
 	bool supportWhirlpool = utility::userHasGoodVersionOfWhirlpool() ;
 
-	Q_UNUSED( e ) ;
+	Q_UNUSED( e )
 
 	auto _plain_dmcrypt = [ this ](){
 
@@ -418,32 +418,26 @@ void createvolume::setOptions( int e )
 		 */
 		auto _add_options = [ & ]( const std::initializer_list<QString>& list ){
 
-			auto _add_option = [ & ]( const QString& algo ){
+			auto _add_option = [ & ]( const QString& algo,const QString& keySize ){
 
-				options->addItem( algo + ".xts-plain64.256.sha256" ) ;
-				options->addItem( algo + ".xts-plain64.256.sha512" ) ;
-				options->addItem( algo + ".xts-plain64.256.sha1" ) ;
-				options->addItem( algo + ".xts-plain64.256.ripemd160" ) ;
+				options->addItem( algo + ".xts-plain64." + keySize + ".sha256" ) ;
+				options->addItem( algo + ".xts-plain64." + keySize + ".sha512" ) ;
+				options->addItem( algo + ".xts-plain64." + keySize + ".sha1" ) ;
+				options->addItem( algo + ".xts-plain64." + keySize + ".ripemd160" ) ;
 
 				if( supportWhirlpool ){
 
-					options->addItem( algo + ".xts-plain64.256.whirlpool" ) ;
-				}
-
-				options->addItem( algo + ".xts-plain64.512.sha256" ) ;
-				options->addItem( algo + ".xts-plain64.512.sha512" ) ;
-				options->addItem( algo + ".xts-plain64.512.sha1" ) ;
-				options->addItem( algo + ".xts-plain64.512.ripemd160" ) ;
-
-				if( supportWhirlpool ){
-
-					options->addItem( algo + ".xts-plain64.512.whirlpool" ) ;
+					options->addItem( algo + ".xts-plain64." + keySize + ".whirlpool" ) ;
 				}
 			} ;
 
 			for( const auto& it : list ){
 
-				_add_option( it ) ;
+				_add_option( it,"512" ) ;
+			}
+			for( const auto& it : list ){
+
+				_add_option( it,"256" ) ;
 			}
 		} ;
 
@@ -1151,7 +1145,18 @@ void createvolume::taskFinished_1( const utility::Task& e )
 		}else{
 			std::atomic_bool exit( false ) ;
 
-			if( utility::clearVolume( volumePath,&exit,2 * 1024 * 1024,[]( int r ){ Q_UNUSED( r ) ; } ).await() == 0 ){
+			auto function = []( quint64 size,quint64 offset ){
+
+				Q_UNUSED( size )
+				Q_UNUSED( offset )
+			} ;
+
+			auto s = quint64( QFileInfo( backUp ).size() ) ;
+
+			if( utility::clearVolume( volumePath,
+						  &exit,
+						  s != 0 ? s : 2 * 1024 * 1024,
+						  function ).await() == 0 ){
 
 				msg.ShowUIOK( tr( "SUCCESS!" ),tr( "Luks volume created successfully." ) ) ;
 			}else{
@@ -1179,18 +1184,18 @@ void createvolume::taskFinished( const utility::Task& e )
 
 	switch ( e.exitCode() ){
 		case 0 : msg.ShowUIOK( tr( "SUCCESS!" ),x ) ;
-		return this->HideUI() ;													break  ;
+		return this->HideUI() ;
 		case 1 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Presented file system is not supported,see documentation for more information" ) ) ;	break  ;
 		case 2 : msg.ShowUIOK( tr( "ERROR!" ),tr( "insufficient privilege to open a system device in read/write mode,\n\
-only root user or members of group zulucrypt can do that" ) ) ;									break  ;
+only root user or members of group zulucrypt can do that" ) ) ;										break  ;
 		case 3 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not create an encrypted volume" ) ) ;					break  ;
 		case 4 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not open volume for writing" ) ) ;					break  ;
 		case 5 : msg.ShowUIOK( tr( "ERROR!" ),tr( "There seem to be an opened mapper associated with the device" ) ) ;		break  ;
 		case 6 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Can not create a volume on a mounted device" ) ) ;				break  ;
-		case 7 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Container file must be bigger than 3MB" ) ) ;					break  ;
+		case 7 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Container file must be bigger than 3MB" ) ) ;				break  ;
 		case 8 : msg.ShowUIOK( tr( "ERROR!" ),tr( "%1 not found" ).arg( ZULUCRYPTmkfs ) ) ;					break  ;
 		case 9 : msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient memory to hold your response" ) ) ;				break  ;
-		case 10: msg.ShowUIOK( tr( "ERROR!" ),tr( "Operation terminated per user request" ) ) ; 				break  ;													break  ;
+		case 10: msg.ShowUIOK( tr( "ERROR!" ),tr( "Operation terminated per user request" ) ) ; 				break  ;
 		case 11: msg.ShowUIOK( tr( "ERROR!" ),tr( "Could not get passphrase in silent mode" ) ) ;				break  ;
 		case 12: msg.ShowUIOK( tr( "ERROR!" ),tr( "Insufficient memory to hold the passphrase" ) ) ;				break  ;
 		case 13: msg.ShowUIOK( tr( "ERROR!" ),tr( "Passphrases do not match" ) ) ;						break  ;
