@@ -779,31 +779,6 @@ void utility::createPlugInMenu( QMenu * menu,const QString& a,const QString& b,c
 	} ) ;
 }
 
-void utility::dropPrivileges( int uid )
-{
-	if( uid == -1 ){
-
-		uid = utility::getUserID() ;
-	}
-
-	if( uid != -1 ){
-
-		auto id = getpwuid( static_cast< uid_t >( uid ) ) ;
-
-		if( id ){
-
-			setenv( "LOGNAME",id->pw_name,1 ) ;
-			setenv( "HOME",id->pw_dir,1 ) ;
-			setenv( "USER",id->pw_name,1 ) ;
-		}
-
-		Q_UNUSED( setgid( static_cast< gid_t >( uid ) ) ) ;
-		Q_UNUSED( setgroups( 1,reinterpret_cast< const gid_t * >( &uid ) ) ) ;
-		Q_UNUSED( setegid( static_cast< gid_t >( uid ) ) ) ;
-		Q_UNUSED( setuid( static_cast< gid_t >( uid ) ) ) ;
-	}
-}
-
 ::Task::future<bool>& utility::openPath( const QString& path,const QString& opener )
 {
 	return ::Task::run( [ = ](){
@@ -946,12 +921,15 @@ static std::function< void( int ) > _closeFunction( const QString& e )
 	} ;
 }
 
-static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
+static bool _writeToVolume( int fd,std::array< char,1024 >& buffer )
 {
-	return write( fd,buffer,bufferSize ) != -1 ;
+	return write( fd,buffer.data(),buffer.size() ) != -1 ;
 }
 
-::Task::future< int >& utility::clearVolume( const QString& volume,std::atomic_bool * exit,size_t volumeSize,std::function< void( int ) > function )
+::Task::future< int >& utility::clearVolume( const QString& volume,
+					     std::atomic_bool * exit,
+					     size_t volumeSize,
+					     std::function< void( quint64 size,quint64 offset ) > function )
 {
 	return ::Task::run( [ volume,exit,volumeSize,function ](){
 
@@ -959,7 +937,9 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 
 		volumePath.replace( "\"","\"\"\"" ) ;
 
-		int r = utility::Task( utility::appendUserUID( "%1 -k -J -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,volumePath ) ).exitCode() ;
+		auto a = utility::appendUserUID( "%1 -k -J -d \"%2\"" ).arg( ZULUCRYPTzuluCrypt,volumePath ) ;
+
+		int r = utility::Task( a ).exitCode() ;
 
 		if( r != 0 ){
 
@@ -975,12 +955,7 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 
 				return 1 ;
 			}else{
-				int i = 0 ;
-				int j = 0 ;
-
-				const int bufferSize = 1024 ;
-
-				char buffer[ bufferSize ] ;
+				std::array< char,1024 > buffer ;
 
 				quint64 size         = _volumeSize( volumeMapperPath,volumeSize ) ;
 				quint64 size_written = 0 ;
@@ -990,7 +965,7 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 					return 0 ;
 				}
 
-				while( _writeToVolume( fd,buffer,bufferSize ) ){
+				while( _writeToVolume( fd,buffer ) ){
 
 					if( *exit ){
 						/*
@@ -998,16 +973,9 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 						 */
 						return 5 ;
 					}else{
-						size_written += bufferSize ;
+						size_written += buffer.size() ;
 
-						i = int( ( size_written * 100 / size ) ) ;
-
-						if( i > j ){
-
-							function( i ) ;
-
-							j = i ;
-						}
+						function( size,size_written ) ;
 
 						if( size_written >= size ){
 
@@ -1111,7 +1079,7 @@ bool utility::useDmCryptForRandomData()
 
 QString utility::localizationLanguage( const QString& program )
 {
-	Q_UNUSED( program ) ;
+	Q_UNUSED( program )
 
 	if( _settings->contains( "LocalizationLanguage" ) ){
 
@@ -1125,7 +1093,7 @@ QString utility::localizationLanguage( const QString& program )
 
 void utility::setLocalizationLanguage( const QString& program,const QString& language )
 {
-	Q_UNUSED( program ) ;
+	Q_UNUSED( program )
 	_settings->setValue( "LocalizationLanguage",language ) ;
 }
 
@@ -1813,7 +1781,7 @@ utility::array_t utility::getWindowDimensions( const QString& application )
 
 void utility::setWindowDimensions( const QString& application,const std::initializer_list<int>& e )
 {
-	Q_UNUSED( application ) ;
+	Q_UNUSED( application )
 
 	QStringList s ;
 
@@ -2043,7 +2011,7 @@ void utility::showTrayIcon( QAction * ac,QObject * obj,bool show )
 
 void utility::trayProperty( QSystemTrayIcon * trayIcon,bool zuluCrypt )
 {
-	Q_UNUSED( zuluCrypt ) ;
+	Q_UNUSED( zuluCrypt )
 
 	if( _settings->contains( "ShowTrayIcon" ) ){
 
@@ -2148,7 +2116,7 @@ void utility::setLocalizationLanguage( bool translate,QMenu * m,const QString& a
 
 void utility::languageMenu( QWidget * w,QMenu * m,QAction * ac,const char * app )
 {
-	Q_UNUSED( w ) ;
+	Q_UNUSED( w )
 
 	auto e = ac->text() ;
 
@@ -2222,7 +2190,7 @@ void utility::setIconMenu( const QString& app,QAction * ac,QWidget * w,
 
 void utility::setIcons( const QString& app,const QString& iconName )
 {
-	Q_UNUSED( app ) ;
+	Q_UNUSED( app )
 	_settings->setValue( "IconName",iconName ) ;
 }
 
@@ -2246,7 +2214,7 @@ QIcon utility::getIcon( const QString& app )
 
 bool utility::autoSetVolumeAsVeraCrypt( const QString& app )
 {
-	Q_UNUSED( app ) ;
+	Q_UNUSED( app )
 
 	if( _settings->contains( "AutoSetVolumeAsVeraCrypt" ) ){
 
@@ -2260,20 +2228,35 @@ bool utility::autoSetVolumeAsVeraCrypt( const QString& app )
 
 void utility::autoSetVolumeAsVeraCrypt( const QString& app,bool set )
 {
-	Q_UNUSED( app ) ;
-
+	Q_UNUSED( app )
 	_settings->setValue( "AutoSetVolumeAsVeraCrypt",set ) ;
 }
 
+int utility::defaultUnlockingVolumeType()
+{
+	if( !_settings->contains( "DefaultUnlockingVolumeType" ) ){
+
+		_settings->setValue( "DefaultUnlockingVolumeType",0 ) ;
+	}
+
+	return _settings->value( "DefaultUnlockingVolumeType" ).toInt() ;
+}
+
+void utility::defaultUnlockingVolumeType( int e )
+{
+	_settings->setValue( "DefaultUnlockingVolumeType",e ) ;
+
+}
+
 void utility::autoOpenFolderOnMount( const QString& app,bool e )
 {
-	Q_UNUSED( app ) ;
+	Q_UNUSED( app )
 	_settings->setValue( "AutoOpenFolderOnMount",e ) ;
 }
 
 bool utility::autoOpenFolderOnMount( const QString& app )
 {
-	Q_UNUSED( app ) ;
+	Q_UNUSED( app )
 
 	if( _settings->contains( "AutoOpenFolderOnMount" ) ){
 
@@ -2373,20 +2356,19 @@ QStringList utility::plainDmCryptOptions()
 			{ "aes.cbc-essiv:sha256.256.sha256" },
 			{ "aes.cbc-essiv:sha256.256.sha512" },
 			{ "aes.cbc-essiv:sha256.256.sha1" },
-			{ "aes.cbc-essiv:sha256.512.ripemd160" },
+			{ "aes.cbc-essiv:sha256.256.ripemd160" },
 			{ "aes.cbc-essiv:sha256.512.sha256" },
 			{ "aes.cbc-essiv:sha256.512.sha512" },
 			{ "aes.cbc-essiv:sha256.512.sha1" },
-			{ "aes.xts-plain64.256.ripemd160" },
+			{ "aes.cbc-essiv:sha256.512.ripemd160" },
 			{ "aes.xts-plain64.256.sha256" },
 			{ "aes.xts-plain64.256.sha512" },
-			{ "aes.xts-plain64.256.sha512" },
 			{ "aes.xts-plain64.256.sha1" },
-			{ "aes.xts-plain64.256.sha1" },
-			{ "aes.xts-plain64.512.ripemd160" },
+			{ "aes.xts-plain64.256.ripemd160" },
 			{ "aes.xts-plain64.512.sha256" },
 			{ "aes.xts-plain64.512.sha512" },
-			{ "aes.xts-plain64.512.sha1" }
+			{ "aes.xts-plain64.512.sha1" },
+			{ "aes.xts-plain64.512.ripemd160" },
 		};
 
 		_settings->setValue( "PlainDmCryptOptions",s ) ;
@@ -2411,7 +2393,7 @@ QStringList utility::supportedFileSystems()
 
 std::pair< bool,QByteArray > utility::getKeyFromNetwork( const QString& e )
 {
-	Q_UNUSED( e ) ;
+	Q_UNUSED( e )
 
 	return { false,QByteArray() } ;
 #if 0
@@ -2467,7 +2449,7 @@ std::pair< bool,QByteArray > utility::getKeyFromNetwork( const QString& e )
 
 void utility::setHDPI( const QString& e )
 {
-	Q_UNUSED( e ) ;
+	Q_UNUSED( e )
 
 #if QT_VERSION >= 0x050600
 
@@ -2980,3 +2962,147 @@ utility::result<QByteArray> utility::yubiKey( const QString& challenge )
 
 	return {} ;
 }
+
+utility::progress::progress( int s,std::function< void( const utility::progress::result& )> function ) :
+	m_offset_last( 0 ),
+	m_total_time( 0 ),
+	m_function( std::move( function ) ),
+	m_duration( s ),
+	m_time( m_duration.timer() ),
+	m_previousTime( m_time.currentMSecsSinceEpoch() )
+{
+}
+
+void utility::progress::update_progress( quint64 size,quint64 offset )
+{
+	int i = int( ( offset * 100 / size ) ) ;
+
+	auto time_expired = m_duration.passed() ;
+
+	if( !time_expired ){
+
+		m_duration.reset() ;
+	}
+
+	if( i > m_progress || time_expired ){
+
+		m_progress = i ;
+
+		double currentTime = m_time.currentMSecsSinceEpoch() ;
+
+		double time_diff = ( currentTime - m_previousTime ) / 1000 ;
+		double offset_diff = offset - m_offset_last ;
+
+		m_total_time = m_total_time + time_diff ;
+
+		QString current_speed = this->speed( offset_diff,time_diff ) ;
+
+		QString average_speed = this->speed( offset,m_total_time ) ;
+
+		double avg_speed = offset / m_total_time ;
+
+		double remaining_data = size - offset ;
+
+		QString eta = this->time( remaining_data / avg_speed ) ;
+
+		m_function( { current_speed,
+			      average_speed,
+			      eta,
+			      this->time( m_total_time ),
+			      i } ) ;
+
+		m_offset_last = offset ;
+		m_previousTime = currentTime ;
+	}
+}
+
+std::function< void( quint64 size,quint64 offset ) > utility::progress::updater_quint()
+{
+	return [ this ]( quint64 size,quint64 offset ){
+
+		this->update_progress( size,offset ) ;
+	} ;
+}
+
+std::function< void( qint64 size,qint64 offset ) > utility::progress::updater_qint()
+{
+	return [ this ]( qint64 size,qint64 offset ){
+
+		this->update_progress( quint64( size ),quint64( offset ) ) ;
+	} ;
+}
+
+QString utility::progress::time( double s )
+{
+	int milliseconds = int( s ) * 1000 ;
+	int seconds      = milliseconds / 1000;
+	milliseconds     = milliseconds % 1000;
+	int minutes      = seconds / 60;
+	seconds          = seconds % 60;
+	int hours        = minutes / 60;
+	minutes          = minutes % 60;
+
+	QTime time;
+	time.setHMS( hours,minutes,seconds,milliseconds ) ;
+	return time.toString( "hh:mm:ss" ) ;
+}
+
+QString utility::progress::speed( double size,double time )
+{
+	QString s ;
+
+	if( size < 1024 ){
+
+		s = "B" ;
+
+	}else if( size <= 1024 * 1024 ){
+
+		s = "KB" ;
+		size = size / 1024 ;
+
+	}else if( size <= 1024 * 1024 * 1024 ){
+
+		s = "MB" ;
+		size = size / ( 1024 * 1024 ) ;
+
+	}else if( size <= 1024 * 1024 * 1024 * 1024ll ){
+
+		s = "GB" ;
+		size = size / ( 1024 * 1024 * 1024 ) ;
+	}else{
+		s = "B" ;
+	}
+
+	size = size / time ;
+
+	return QString::number( size,'f',2 ) + " " + s + "/s" ;
+}
+
+utility::duration::duration( long miliseconds ) : m_milliseconds( miliseconds )
+{
+	this->reset() ;
+}
+
+bool utility::duration::passed()
+{
+	auto now = m_time.currentMSecsSinceEpoch() ;
+
+	if( now - m_start_time >= m_milliseconds ){
+
+		this->reset() ;
+
+		return true ;
+	}else{
+		return false ;
+	}
+}
+
+void utility::duration::reset()
+{
+	m_start_time = m_time.currentMSecsSinceEpoch() ;
+}
+
+QDateTime& utility::duration::timer()
+{
+	return m_time ;
+}
